@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 
 """
-SimpleGUICS2Pygame package (November 8, 2013)
+SimpleGUICS2Pygame package (December 13, 2013)
 
 It is primarily a standard Python_ (2 **and** 3) module
 reimplementing the SimpleGUI particular module of CodeSkulptor_
@@ -29,8 +29,7 @@ http://www.opimedia.be/
 .. _Python: http://www.python.org/
 .. _`Unofficial Windows Binaries`: http://www.lfd.uci.edu/~gohlke/pythonlibs/#pygame
 
-Started on May 21, 2013
-
+v.01.03.00 --- December, 2013
 v.01.02.00 --- November 8, 2013
 v.01.01.00 --- November 1st, 2013
 v.01.00.02 --- October 31, 2013
@@ -40,9 +39,10 @@ v.00.92.00 --- June 27, 2013
 v.00.91.00 --- June 23, 2013
 v.00.90.10 --- June 19, 2013
 v.00.90.00 --- June 13, 2013
+Started on May 21, 2013
 """
 
-_VERSION = '01.02.00'
+_VERSION = '01.03.00'
 """
 Version of SimpleGUICS2Pygame package.
 """
