@@ -2,14 +2,14 @@
 # -*- coding: latin-1 -*-
 
 """
-RiceRocks (Asteroids) (November 8, 2013)
+RiceRocks (Asteroids) (December 13, 2013)
 
 My slightly retouched solution of the mini-project #8 of the course
 https://www.coursera.org/course/interactivepython (Coursera 2013).
 
 Run on (maybe very slow on some browsers):
-  - Chrome 27
-  - Firefox 21
+  - Chrome 31
+  - Firefox 26
   - Safari 5.1.7 (without sounds)
   - Python 2 and 3 with SimpleGUICS2Pygame.
 
@@ -24,12 +24,12 @@ import math
 import random
 
 try:
-    from user23_XEsEdVoFmntP29T import Loader
+    from user27_rSvHGawbvoYISaV import Loader
 
     import simplegui
 
     SIMPLEGUICS2PYGAME = False
-except:
+except ImportError:
     from SimpleGUICS2Pygame.simplegui_lib_loader import Loader
 
     import SimpleGUICS2Pygame.simpleguics2pygame as simplegui
@@ -140,7 +140,7 @@ class RiceRocks:
         self.nb_bombs = None
         self.score = 0
         self.started = False
-        self.time = 0.5
+        self.time = 0.5  # ??? 0
 
         self.explosions = []
         self.live_explosions = []
@@ -184,6 +184,7 @@ class RiceRocks:
                               (SCREEN_WIDTH, SCREEN_HEIGHT))
 
         # Draw animated background
+        # ???
         center = self.img_infos['debris'].get_center()
         size = self.img_infos['debris'].get_size()
 
@@ -898,7 +899,7 @@ class Ship(Sprite):
         """
         self.angle += math.pi
 
-    def shoot(self):
+    def shot(self):
         """
         Launch a missile.
         """
@@ -1016,7 +1017,7 @@ def keydown(key):
         elif key == simplegui.KEY_MAP['down']:
             ricerocks.my_ship.flip()
         elif key == simplegui.KEY_MAP['space']:
-            ricerocks.my_ship.shoot()
+            ricerocks.my_ship.shot()
         elif key == simplegui.KEY_MAP['Z']:
             ricerocks.bomb_explode()
 
