@@ -1,11 +1,12 @@
 # -*- coding: latin-1 -*-
 
 """
-simplegui_lib (November 8, 2013)
+simplegui_lib (December 13, 2013)
 
 Some functions and classes to help
 in SimpleGUI of CodeSkulptor,
 from `simplegui_lib_draw`,
+`simplegui_lib_fps`,
 `simplegui_lib_keys`
 and `simplegui_lib_loader`.
 
@@ -18,9 +19,11 @@ http://www.opimedia.be/
 
 try:
     from user23_HY71NDvHu7WKaMa import draw_rect, draw_text_side
-    from user23_9gk3AFlrXCZJFMe import Keys
-    from user23_XEsEdVoFmntP29T import Loader
-except:
+    from user27_1vuhJpK9euOgnic import FPS
+    from user27_KX2DJkIN6iSjW19 import Keys
+    from user27_rSvHGawbvoYISaV import Loader
+except ImportError:
     from SimpleGUICS2Pygame.simplegui_lib_draw import draw_rect, draw_text_side
+    from SimpleGUICS2Pygame.simplegui_lib_fps import FPS
     from SimpleGUICS2Pygame.simplegui_lib_keys import Keys
     from SimpleGUICS2Pygame.simplegui_lib_loader import Loader
